// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  crystal growth group                                                  ==
// ==                                                                        ==
// ==  Stiftung caesar                                                       ==
// ==  Ludwig-Erhard-Allee 2                                                 ==
// ==  53175 Bonn                                                            ==
// ==  germany                                                               ==
// ==                                                                        ==
// ============================================================================
// ==                                                                        ==
// ==  http://www.caesar.de/cg/AMDiS                                         ==
// ==                                                                        ==
// ============================================================================

/** \file Utilities.h */

#ifndef AMDIS_UTILITIES_H
#define AMDIS_UTILITIES_H

#include <vector>
#include <algorithm>



template <typename T>
std::vector<T> inline invert_reorder(const std::vector<T>& v)
{
    T my_max= *std::max_element(v.begin(), v.end()) + 1;
    std::vector<T> u(my_max, T(-1));
    for (int i= 0; i < v.size(); i++) 
	if (v[i] >= 0) {
	    assert(u[v[i]] == -1); // check double insertion
	    u[v[i]]= T(i);
    }
    assert(find(u.begin(), u.end(), T(-1)) == u.end()); // check if all entries are set
    return u;
}

#endif  // AMDIS_UTILITIES_H
